@@ -1,3 +1,4 @@
+import requests
 from django.conf import settings
 from django.db import models
 from django.contrib.auth import get_user_model
@@ -118,14 +119,30 @@ def send_email_on_notification(sender, instance, created, **kwargs):
         if email_from is None or not instance.user.settings.receiveMail:
             return
 
+         # get author name, and store in who
+        try:
+            # local author
+            if instance.author.startswith(settings.SITE_URL):
+                who = str(Model.resolve_id(instance.author.replace(settings.SITE_URL, '')).get_full_name())
+            # external author
+            else:
+                who = requests.get(instance.author).json()['name']
+        except:
+            who = "Quelqu'un"
+
+        on = str(getattr(settings, 'INSTANCE_DEFAULT_CLIENT', False)) \
+            + '/job-offers/job-offers-detail/@' + instance.object + '@'
+
         joboffer = JobOffer.objects.get(urlid=instance.object)
         message_html = render_to_string('joboffer/email.html', {
             "instance": joboffer,
-            "fnk": False
+            "fnk": False,
+            "author": who,
+            "on": on
         })
 
         send_mail(
-            "Une nouvelle offre pourrait vous intéresser",
+            "Une nouvelle offre pourrait t'intéresser",
             to_text(message_html),
             email_from,
             [instance.user.email],
